<p align="center" style="text-align:center">
  <img src="resources/sensai-utils-logo.svg#gh-light-mode-only" style="width:500px">
  <img src="resources/sensai-utils-logo-dark-mode.svg#gh-dark-mode-only" style="width:500px">
  <br>
  Utils from sensAI, the Python library for sensible AI

  <div align="center" style="text-align:center">
  <a href="https://pypi.org/project/sensai-utils/" style="text-decoration:none"><img src="https://img.shields.io/pypi/v/sensai-utils.svg" alt="PyPI"></a>
  <a href="https://raw.githubusercontent.com/opcode81/sensAI-utils/master/LICENSE" style="text-decoration:none"><img alt="License" src="https://img.shields.io/pypi/l/sensai-utils"></a>
  <a href="https://github.com/opcode81/sensAI-utils/actions/workflows/test.yaml" style="text-decoration:none"><img src="https://github.com/opcode81/sensAI-utils/actions/workflows/test.yaml/badge.svg" alt="Build status"></a>
  </div>
</p>


# sensAI-utils

This project provides the `util` package from [sensAI](https://github.com/opcode81/sensAI), the Python library for 
sensible AI, allowing it to be used without the additional dependencies of sensAI.

sensAI's utility classes are general-purpose and mostly not specific to AI use cases. They are useful in a wide range of
applications.

## Installation

sensAI-utils can be installed via pip:

```
pip install sensai-utils
```

sensAI-utils contains the single package `sensai.utils`.

sensAI-utils is a subset of sensAI and its version aligns with the version of sensAI from which it was extracted.
You can choose to upgrade to the full sensAI library at any time by installing `sensai` with the same version number 
at any time.

## Usage

See [sensAI's documention of the util package](https://opcode81.github.io/sensAI/docs/sensai/util.html).

## Contributing

Contributions should be made directly in [sensAI](https://github.com/opcode81/sensAI).